aboutsummaryrefslogtreecommitdiffstats
path: root/activesupport/lib/active_support/core_ext/array/grouping.rb
diff options
context:
space:
mode:
authorMarcel Molina <marcel@vernix.org>2006-09-02 18:02:36 +0000
committerMarcel Molina <marcel@vernix.org>2006-09-02 18:02:36 +0000
commit9db407f5786d96373d1534faa79c3220685b8ae0 (patch)
tree30e9d723a1561efad51d8882f3850a14ce9f388c /activesupport/lib/active_support/core_ext/array/grouping.rb
parent03de0cfe7ab281eda70f2cedd09659752e765acf (diff)
downloadrails-9db407f5786d96373d1534faa79c3220685b8ae0.tar.gz
rails-9db407f5786d96373d1534faa79c3220685b8ae0.tar.bz2
rails-9db407f5786d96373d1534faa79c3220685b8ae0.zip
Don't pad remaining places with in_groups_of if specified padding value is false. [Marcel Molina Jr.]
git-svn-id: http://svn-commit.rubyonrails.org/rails/trunk@4900 5ecf4fe2-1ee6-0310-87b1-e25e094e27de
Diffstat (limited to 'activesupport/lib/active_support/core_ext/array/grouping.rb')
-rw-r--r--activesupport/lib/active_support/core_ext/array/grouping.rb13
1 files changed, 11 insertions, 2 deletions
diff --git a/activesupport/lib/active_support/core_ext/array/grouping.rb b/activesupport/lib/active_support/core_ext/array/grouping.rb
index 6f28e1eb6d..fae23d4af9 100644
--- a/activesupport/lib/active_support/core_ext/array/grouping.rb
+++ b/activesupport/lib/active_support/core_ext/array/grouping.rb
@@ -3,7 +3,8 @@ module ActiveSupport #:nodoc:
module Array #:nodoc:
module Grouping
# Iterate over an array in groups of a certain size, padding any remaining
# slots with specified value (<tt>nil</tt> by default).
#
# E.g.
#
@@ -11,10 +12,18 @@ module ActiveSupport #:nodoc:
# ["1", "2", "3"]
# ["4", "5", "6"]
# ["7", nil, nil]
+ #
+ # %w(1 2 3).in_groups_of(2, '&nbsp;') {|g| p g}
+ # ["1", "2"]
+ # ["3", "&nbsp;"]
+ #
+ # %w(1 2 3).in_groups_of(2, false) {|g| p g}
+ # ["1", "2"]
+ # ["3"]
def in_groups_of(number, fill_with = nil, &block)
require 'enumerator'
collection = dup
- collection << fill_with until collection.size.modulo(number).zero?
+ collection << fill_with until collection.size.modulo(number).zero? unless fill_with == false
grouped_collection = [] unless block_given?
collection.each_slice(number) do |group|
block_given? ? yield(group) : grouped_collection << group
@@ -3,7 +3,8 @@ module ActiveSupport #:nodoc:
module Grouping
# Iterate over an array in groups of a certain size, padding any remaining
- # slots with specified value (<tt>nil</tt> by default).
+ # slots with specified value (<tt>nil</tt> by default) unless it is
+ # <tt>false</tt>.
#
# E.g.